package com.diagbot.facade;

import com.diagbot.client.bean.SearchData;
import com.diagbot.enums.LisSourceEnum;
import com.diagbot.util.BeanUtil;
import com.diagbot.util.ListUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.LisResult;
import com.diagbot.vo.PushVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:zhaops
 * @time: 2019/5/9 15:40
 */
@Component
public class AssembleFacade {
    @Autowired
    private LisMappingFacade lisMappingFacade;

    /**
     * 拼装数据
     *
     * @param pushVO
     * @return SearchData
     */
    public SearchData assembleData(PushVO pushVO) {
        SearchData searchData = new SearchData();
        searchData.setAge(pushVO.getAge());
        searchData.setSymptom(pushVO.getSymptom());
        searchData.setVital(pushVO.getVital());
        searchData.setPacs(pushVO.getPacs());
        searchData.setPast(pushVO.getPast());
        searchData.setOther(pushVO.getOther());
        searchData.setDiag(pushVO.getDiag());
        searchData.setDisType(pushVO.getDisType());
        searchData.setAdverseEvent(pushVO.getAdverseReactions());
        searchData.setScaleName(pushVO.getScaleName());
        searchData.setDiseaseName(pushVO.getDiseaseName());
        searchData.setIndications(pushVO.getIndications());
        searchData.setFeatureType(pushVO.getFeatureType());
        searchData.setSysCode("1");
        searchData.setLength(10);

        switch (pushVO.getSex()) {
            case 1:
                searchData.setSex("M");
                break;
            case 2:
                searchData.setSex("F");
                break;
            default:
                searchData.setSex("A");
                break;
        }

        //化验项映射,转公表
        if (ListUtil.isNotEmpty(pushVO.getLis())) {
            Map<String, Map<String, String>> lisConfigMap = lisMappingFacade.getLisMapping_NotEmptyItemName();
            Map<String, String> lisConfigWithEmptyItemNameMap = lisMappingFacade.getLisConfig_EmptyItemName();
            for (LisResult lisResult : pushVO.getLis()) {
                //source=0 icss页面数据，source=1 外部导入数据，外部导入数据不处理
                if (!lisResult.getSource().equals(LisSourceEnum.Inner.getKey())) {
                    continue;
                }
                if (StringUtil.isNotBlank(lisResult.getName())) {
                    if (StringUtil.isNotBlank(lisResult.getDetailName())) {
                        Map<String, String> detailMap = lisConfigMap.get(lisResult.getName());
                        if (null != detailMap && detailMap.size() > 0 && StringUtil.isNotBlank(detailMap.get(lisResult.getDetailName()))) {
                            lisResult.setUniqueName(detailMap.get(lisResult.getDetailName()));
                        }
                    } else {
                        lisResult.setUniqueName(lisConfigWithEmptyItemNameMap.get(lisResult.getName()));
                    }
                }
            }
            List<LisResult> lisResultList = BeanUtil.listCopyTo(pushVO.getLis(), LisResult.class);
            searchData.setLisArr(lisResultList);
        }
        return searchData;
    }
}